int save_enemy(char *, enemy *);
 int read_enemy(char *, char *, enemy *);
int save_bullet(char *, bullet *);
 int read_bullet(char *, char *, bullet *);
int save_point(char *, point *);
 int read_point(char *, char *, point *);
int save_moderately_finepoint(char *, moderately_finepoint *);
 int read_moderately_finepoint(char *, char *, moderately_finepoint *);
int save_mission(char *, mission *);
 int read_mission(char *, char *, mission *);
int save_tux_t(char *, tux_t *);
 int read_tux_t(char *, char *, tux_t *);
int save_item(char *, item *);
 int read_item(char *, char *, item *);
int save_finepoint(char *, finepoint *);
 int read_finepoint(char *, char *, finepoint *);
int save_melee_shot(char *, melee_shot *);
 int read_melee_shot(char *, char *, melee_shot *);
int save_configuration_for_freedroid(char *, configuration_for_freedroid *);
 int read_configuration_for_freedroid(char *, char *, configuration_for_freedroid *);
int save_gps(char *, gps *);
 int read_gps(char *, char *, gps *);
